@@ -83,6 +83,9 @@ INTERNALERROR_ENCRYPTION = 'InternalError.Encryption'
 # 生成唯一ID错误。
 INTERNALERROR_GENERATEID = 'InternalError.GenerateId'
 
+# Pdf合成错误。
+INTERNALERROR_PDF = 'InternalError.Pdf'
+
 # 上传印章失败。
 INTERNALERROR_SEALUPLOAD = 'InternalError.SealUpload'
 
@@ -194,6 +197,9 @@ INVALIDPARAMETER_MENUSTATUS = 'InvalidParameter.MenuStatus'
 # 缺少必填参数的值。
 INVALIDPARAMETER_MISSINGREQUIREDPARAMETERVALUE = 'InvalidParameter.MissingRequiredParameterValue'
 
+# 手机号码不正确。
+INVALIDPARAMETER_MOBILE = 'InvalidParameter.Mobile'
+
 # 姓名不符合要求。
 INVALIDPARAMETER_NAME = 'InvalidParameter.Name'
 
@@ -326,6 +332,9 @@ OPERATIONDENIED_FILEDELETED = 'OperationDenied.FileDeleted'
 # 流程已终止。
 OPERATIONDENIED_FLOWHASTERMINATED = 'OperationDenied.FlowHasTerminated'
 
+# 签署流程状态不正确，请检查后重试。
+OPERATIONDENIED_FLOWSTATUSFORBID = 'OperationDenied.FlowStatusForbid'
+
 # 禁止操作。
 OPERATIONDENIED_FORBID = 'OperationDenied.Forbid'
 
@@ -344,6 +353,9 @@ OPERATIONDENIED_NOIDENTITYVERIFY = 'OperationDenied.NoIdentityVerify'
 # 流程配额不足。
 OPERATIONDENIED_NOQUOTA = 'OperationDenied.NoQuota'
 
+# 不属于企业超管或者法人。
+OPERATIONDENIED_NOTBELONGSUPERADMINORLEGALPERSON = 'OperationDenied.NotBelongSuperAdminOrLegalPerson'
+
 # 操作类型不支持。
 OPERATIONDENIED_OPERATETYPE = 'OperationDenied.OperateType'
 
@@ -353,9 +365,18 @@ OPERATIONDENIED_OPERATORHASNOPERMISSION = 'OperationDenied.OperatorHasNoPermissi
 # 超出查询上限。
 OPERATIONDENIED_OUTQUERYLIMIT = 'OperationDenied.OutQueryLimit'
 
+# 当前企业员工没有开通境外签署能力。
+OPERATIONDENIED_OVERSEAABILITYNOTOPEN = 'OperationDenied.OverseaAbilityNotOpen'
+
+# 出证计费额度不足。
+OPERATIONDENIED_PROVENOQUOTA = 'OperationDenied.ProveNoQuota'
+
 # 用户不归属于当前企业，无法操作，请检查后重试。
 OPERATIONDENIED_USERNOTINORGANIZATION = 'OperationDenied.UserNotInOrganization'
 
+# 未开通功能白名单，请联系客服处理。
+OPERATIONDENIED_WHITELISTFORBID = 'OperationDenied.WhiteListForbid'
+
 # 资源不存在。
 RESOURCENOTFOUND = 'ResourceNotFound'
 
@@ -374,6 +395,9 @@ RESOURCENOTFOUND_FILE = 'ResourceNotFound.File'
 # 未找到对应流程。
 RESOURCENOTFOUND_FLOW = 'ResourceNotFound.Flow'
 
+# 签署流程的签署人不存在，请检查后重试。
+RESOURCENOTFOUND_FLOWAPPROVER = 'ResourceNotFound.FlowApprover'
+
 # 签署人信息不存在，请检查后重试。
 RESOURCENOTFOUND_FLOWAPPROVERS = 'ResourceNotFound.FlowApprovers'
 
@@ -392,6 +416,9 @@ RESOURCENOTFOUND_TEAMWORKORGANIZATION = 'ResourceNotFound.TeamWorkOrganization'
 # 模板不存在。
 RESOURCENOTFOUND_TEMPLATE = 'ResourceNotFound.Template'
 
+# Url不存在。
+RESOURCENOTFOUND_URL = 'ResourceNotFound.URL'
+
 # 用户信息不存在。
 RESOURCENOTFOUND_USER = 'ResourceNotFound.User'
 
@@ -404,6 +431,12 @@ RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 未授权下载权限。
+UNAUTHORIZEDOPERATION_UNAUTHORIZEDOPERATIONDOWNLOAD = 'UnauthorizedOperation.UnauthorizedOperationDownload'
+
+# 企业没有被授权。
+UNAUTHORIZEDOPERATION_UNAUTHORIZEDOPERATIONORGANIZATION = 'UnauthorizedOperation.UnauthorizedOperationOrganization'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
