@@ -95,7 +95,7 @@ class GmeClient(AbstractClient):
 
 
     def CreateCustomization(self, request):
-        """用户使用该接口可以创建语音消息转文本自学习模型，以供识别调用
+        """用户使用该接口可以创建语音消息转文本热句模型，以供识别调用
 
         :param request: Request instance for CreateCustomization.
         :type request: :class:`tencentcloud.gme.v20180711.models.CreateCustomizationRequest`
@@ -153,7 +153,7 @@ class GmeClient(AbstractClient):
 
 
     def DeleteCustomization(self, request):
-        """用户通过该接口可以删除语音消息转文本自学习模型
+        """用户通过该接口可以删除语音消息转文本热句模型
 
         :param request: Request instance for DeleteCustomization.
         :type request: :class:`tencentcloud.gme.v20180711.models.DeleteCustomizationRequest`
@@ -473,7 +473,7 @@ class GmeClient(AbstractClient):
 
 
     def GetCustomizationList(self, request):
-        """查询语音消息转文本自学习模型列表
+        """查询语音消息转文本热句模型列表
 
         :param request: Request instance for GetCustomizationList.
         :type request: :class:`tencentcloud.gme.v20180711.models.GetCustomizationListRequest`
@@ -531,7 +531,7 @@ class GmeClient(AbstractClient):
 
 
     def ModifyCustomization(self, request):
-        """用户通过该接口可以更新语音消息转文本自学习模型。
+        """用户通过该接口可以更新语音消息转文本热句模型。
 
         :param request: Request instance for ModifyCustomization.
         :type request: :class:`tencentcloud.gme.v20180711.models.ModifyCustomizationRequest`
@@ -560,7 +560,7 @@ class GmeClient(AbstractClient):
 
 
     def ModifyCustomizationState(self, request):
-        """通过该接口，用户可以修改语音消息转文本自学习模型状态，上下线自学习模型
+        """通过该接口，用户可以修改语音消息转文本热句模型状态，上下线热句模型
 
         :param request: Request instance for ModifyCustomizationState.
         :type request: :class:`tencentcloud.gme.v20180711.models.ModifyCustomizationStateRequest`
@@ -589,7 +589,9 @@ class GmeClient(AbstractClient):
 
 
     def ModifyUserMicStatus(self, request):
-        """修改用户麦克风状态。
+        """**接口作用**：此接口用于修改房间用户的麦克风状态，例如房间内用户麦克风为打开状态，可调用此接口将该用户麦克风进行关闭，关闭后即使该用户使用客户端接口 EnableMic 打开麦克风，依然无法与房间内成员通话，属于被禁言状态。该状态持续到此用户退房后失效，或者调用该接口重新打开此用户麦克风状态。
+        **接口应用场景**：此接口多用于游戏业务中台或者风控后台，对一些发表不当言论的玩家进行禁言处理。
+        **接口使用前提**：目前 ModifyUserMicStatus 接口通过白名单开放，如需使用，需要 [提交工单申请](https://console.cloud.tencent.com/workorder/category?level1_id=438&level2_id=445&source=0&data_title=%E6%B8%B8%E6%88%8F%E5%A4%9A%E5%AA%92%E4%BD%93%E5%BC%95%E6%93%8EGME&step=1)。
 
         :param request: Request instance for ModifyUserMicStatus.
         :type request: :class:`tencentcloud.gme.v20180711.models.ModifyUserMicStatusRequest`
@@ -672,7 +674,7 @@ class GmeClient(AbstractClient):
         <h4 id="Callback_Declare"><b>回调相关说明：</b></h4>
         <li>如果在请求参数中指定了回调地址参数 Callback，即一个 HTTP(S) 协议接口的 URL，则需要支持 POST 方法，传输数据编码采用 UTF-8。</li>
         <li>在推送回调数据后，接收到的 HTTP 状态码为 200 时，表示推送成功。</li>
-        <li>HTTP 头参数说明：</li>
+        <li>HTTP 请求参数（query）说明：</li>
         <table>
         <thread>
         <tr>
