@@ -35,6 +35,9 @@ INVALIDPARAMETER_CONFLICTPARAMETER = 'InvalidParameter.ConflictParameter'
 # 无效用户名。
 INVALIDPARAMETER_INVALIDUSERNAME = 'InvalidParameter.InvalidUsername'
 
+# 参数名称重复。
+INVALIDPARAMETER_PARAMETERNAMEDUPLICATED = 'InvalidParameter.ParameterNameDuplicated'
+
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
@@ -86,12 +89,18 @@ INVALIDPARAMETERVALUE_INVALIDOUTPUTCOSBUCKETURL = 'InvalidParameterValue.Invalid
 # OutputCOSKeyPrefix 无效。
 INVALIDPARAMETERVALUE_INVALIDOUTPUTCOSKEYPREFIX = 'InvalidParameterValue.InvalidOutputCOSKeyPrefix'
 
+# 无效的时间格式。
+INVALIDPARAMETERVALUE_INVALIDTIMEFORMAT = 'InvalidParameterValue.InvalidTimeFormat'
+
 # 用户名不合法。
 INVALIDPARAMETERVALUE_INVALIDUSERNAME = 'InvalidParameterValue.InvalidUsername'
 
 # 命令执行路径不合法。
 INVALIDPARAMETERVALUE_INVALIDWORKINGDIRECTORY = 'InvalidParameterValue.InvalidWorkingDirectory'
 
+# 调用时间已过期。
+INVALIDPARAMETERVALUE_INVOKETIMEEXPIRED = 'InvalidParameterValue.InvokeTimeExpired'
+
 # 已启用自定义参数功能，但缺失自定义参数信息。
 INVALIDPARAMETERVALUE_LACKOFPARAMETERINFO = 'InvalidParameterValue.LackOfParameterInfo'
 
@@ -152,6 +161,9 @@ RESOURCENOTFOUND_INSTANCENOTFOUND = 'ResourceNotFound.InstanceNotFound'
 # 执行活动未找到。
 RESOURCENOTFOUND_INVOCATIONNOTFOUND = 'ResourceNotFound.InvocationNotFound'
 
+# 角色不存在。
+RESOURCENOTFOUND_ROLENOTFOUND = 'ResourceNotFound.RoleNotFound'
+
 # Agent 未安装。
 RESOURCEUNAVAILABLE_AGENTNOTINSTALLED = 'ResourceUnavailable.AgentNotInstalled'
 
